@@ -36,6 +36,7 @@ generic.predict.rfsrc <-
   gk.quantile <- is.hidden.gk.quantile(user.option)
   prob <- is.hidden.prob(user.option)
   prob.epsilon <- is.hidden.prob.epsilon(user.option)
+  chunkify  <- is.hidden.chunkify(user.option)
   ## set the family
   family <- object$family
   ## incoming parameter checks: all are fatal
@@ -160,7 +161,7 @@ generic.predict.rfsrc <-
   }
     else {
       object.version <- as.integer(unlist(strsplit(object$version, "[.]")))
-      installed.version <- as.integer(unlist(strsplit("2.12.1", "[.]")))
+      installed.version <- as.integer(unlist(strsplit("2.13.0", "[.]")))
       minimum.version <- as.integer(unlist(strsplit("2.3.0", "[.]")))
       object.version.adj <- object.version[1] + (object.version[2]/10) + (object.version[3]/100)
       installed.version.adj <- installed.version[1] + (installed.version[2]/10) + (installed.version[3]/100)
@@ -588,6 +589,7 @@ generic.predict.rfsrc <-
                                              data.pass.predict.bits +
                                              experimental.bits),
                                   ## >>>> start of maxi forest object >>>>
+                                  as.integer(chunkify),
                                   as.integer(ntree),
                                   as.integer(n),
                                   list(as.integer(length(yvar.types)),
