@@ -18,6 +18,11 @@ plot.variable.rfsrc <- function(
   subset,
   ...)
 {
+  ## --------------------------------------------------------------
+  ##   
+  ##   coherence checks
+  ##
+  ## --------------------------------------------------------------
   ## is this a synthetic forest?
   if (sum(inherits(x, c("rfsrc", "synthetic"), TRUE) == c(1, 2)) == 2) {
     x <- x$rfSyn
@@ -33,10 +38,18 @@ plot.variable.rfsrc <- function(
   if (object$family == "unsupv") {
     stop("this function does not apply to unsupervised forests")
   }
+  if (inherits(object, "anonymous")) {
+      stop("this function does work with anonymous forests")
+  }    
   ## terminate if a partial plot is requested but no forest is found
   if (partial && (is.null(object$forest) || !object$forest$forest)) {
     stop("forest is empty:  re-run rfsrc (grow call) with forest=TRUE")
   }
+  ## --------------------------------------------------------------
+  ##   
+  ##   preliminary processing
+  ##
+  ## --------------------------------------------------------------
   ## if missing data was imputed then overlay the missing data for x
   ## bug reported by John Ehrlinger
   xvar <- object$xvar
@@ -303,7 +316,7 @@ plot.variable.rfsrc <- function(
     class(plot.variable.obj) <- c("rfsrc", "plot.variable", family)
   }
   ## ---------------------------------------------------------------------------------
-  ## (TBD TBD) Currently, the plot.variable family is not implemented!
+  ## TBD TBD Currently, the plot.variable family is not implemented!
   ## Just pull the precomputed variables ...
     else {
       plot.variable.obj <- object
@@ -455,190 +468,4 @@ plot.variable.rfsrc <- function(
   ## Return the plot.variable object for reuse
   invisible(plot.variable.obj)
 }
-## --------------------------------------------------------------------------------------------
-##
-## extraction function when partial=FALSE
-##
-## --------------------------------------------------------------------------------------------
-extract.pred <- function(obj, type, subset, time, m.target, target, oob = oob) {
-  ## Coerce the (potentially) multivariate object if necessary.
-  obj <- coerce.multivariate(obj, m.target)
-  ## decide if OOB or in-bag values are requested
-  if (oob == FALSE) {
-    if (is.null(obj$predicted)) {
-      stop("inbag requested but inbag values are not available in the grow object")
-    }
-    pred <- obj$predicted
-    surv <- obj$survival
-    chf <- obj$chf
-    cif <- obj$cif
-  }
-  else {
-    if (is.null(obj$predicted.oob)) {
-      stop("oob requested but oob values are not available in the grow object")
-    }
-    pred <- obj$predicted.oob
-    surv <- obj$survival.oob
-    chf <- obj$chf.oob
-    cif <- obj$cif.oob
-  }
-  ## Survival and competing risk families.
-  if (grepl("surv", obj$family)) {
-    ## Competing risks:
-    if (obj$family == "surv-CR") {
-      n <- dim(pred)[1]
-      if (missing(subset)) subset <- 1:n
-      ## Default is first event type.
-      if (missing(target)) target <- 1
-      type <- match.arg(type, c("years.lost", "cif", "chf"))
-      ## Get the index of the closest point of the grow time interest vector.
-      time.idx <-  max(which(obj$time.interest <= time))
-      return(switch(type,
-                    "years.lost" = pred[subset, target],
-                    "cif"        = cif[subset, time.idx, target],
-                    "chf"        = chf[subset, time.idx, target]
-                    ))
-    }
-    ## Right-censored:
-    else {
-      n <- length(pred)
-      if (missing(subset)) subset <- 1:n
-      type <- match.arg(type, c("rel.freq", "mort", "chf", "surv"))
-      ## Get the index of the closest point of the grow time interest vector.
-      time.idx <-  max(which(obj$time.interest <= time))
-      return(switch(type,
-                    "rel.freq" = pred[subset]/max(n, na.omit(pred)),
-                    "mort"     = pred[subset],
-                    "chf"      = 100 * chf[subset, time.idx],
-                    "surv"     = 100 * surv[subset, time.idx]
-                    ))
-    }
-  }
-  ## The object has been coerced.  It will be univariate.
-  else {
-    if (obj$family == "class") {
-      n <- dim(pred)[1]
-      if (missing(subset)) subset <- 1:n
-      type <- match.arg(type, c("prob", "bayes"))
-      ## The default is first class label.
-      if (missing(target)) target <- 1
-      prob <- pred[subset,, drop = FALSE]
-      return(switch(type,
-                    "prob" = prob[, target],
-                    "bayes" =  get.bayes.rule(prob)))
-    }
-    else {      
-      n <- length(pred)
-      if (missing(subset)) subset <- 1:n
-      return(pred[subset])
-    }
-  }
-}
-## --------------------------------------------------------------------------------------------
-##
-## extraction function when partial=TRUE
-## Note that currently only one (1) time point is requested via the
-## plot.variable() R-wrapper.  Only one (1) is allowed.
-## Additional time points can be specified
-## using the partial.rfsrc() wrapper, and then extracted without any
-## additional calls to the native code.  The extract call
-## is limited to only one (1) time point on each call.
-## The same protocol holds for m.target.
-##
-## --------------------------------------------------------------------------------------------
-extract.partial.pred <- function(obj, type, subset, m.target, target) {
-  ## Survival families
-  if (grepl("surv", obj$family)) {
-    n <- dim(obj$survOutput)[1]
-    if (missing(subset)) {
-      subset <- 1:n
-    }
-    time.idx <-  1
-    ## Competing risks:
-    if (obj$family == "surv-CR") {
-      ## Default is first event type.
-      if (missing(target)) target <- 1
-      type <- match.arg(type, c("years.lost", "cif", "chf"))
-      return(switch(type,
-                    "years.lost" = obj$survOutput[subset, target, ],
-                    "cif" = obj$survOutput[subset, time.idx, target, ],
-                    "chf" = obj$survOutput[subset, time.idx, target, ]
-                    ))
-    }
-    ## Right censored:
-      else {
-        if (type == "rel.freq") {
-          sz <- apply(obj$survOutput[subset, ], 2, function(x) {length(na.omit(x))})
-          rs <- t(apply(obj$survOutput[subset, ], 1, function(x) {x / sz}))
-        }
-        return(switch(type,
-                      "rel.freq" = rs,
-                      "mort"     = obj$survOutput[subset, ],
-                      "chf"      =  obj$survOutput[subset, time.idx, ],
-                      "surv"     =  obj$survOutput[subset, time.idx, ]
-                      ))
-      }
-  }
-    else {
-      ## Univariate and multivariate families:
-      ## The incoming partial object is always presented in a mulitvariate list, regardless of whether
-      ## the grow object was univariate or multivariate.  There is no coersion.  In a multivariate case,
-      ## m.target is coherent.  But in a univariate case, it will be NULL.  As a result, we
-      ## accomodate for the NULL case by grabbing the first (and actually only) valid output below, in
-      ## order to parse the multivariate list correctly.
-      ## We are either classification or regression but we don't know which yet.
-      regrClassTarget <- NULL
-      ## It doesn't matter whether we process regression or classification first.
-      ## But one and only one family will be processed.
-      if (is.null(regrClassTarget)) {
-        if (!is.null(obj$classOutput)) {
-          if (is.null(m.target)) {
-            ## Grab the first outcome!  It will exist, as this is the univariate case.
-            m.target <- names(obj$classOutput)[1]
-          }
-          regrClassTarget <- which (names(obj$classOutput) == m.target)
-          ## Classification.
-          if (length(regrClassTarget) > 0) {
-            if (length(regrClassTarget) > 1) {
-              ## Safety check in case m.target was incorrect coming into this routine.
-              stop("Invalid number of target outcomes specified in partial plot extraction.")
-            }
-            type <- match.arg(type, c("prob", "bayes"))
-            ## Default is first class label.
-            if (missing(target)) target <- 1
-            n <- dim(obj$classOutput[[regrClassTarget]])[1]
-            if (missing(subset)) subset <- 1:n
-            return(switch(type,
-                          "prob" = obj$classOutput[[regrClassTarget]][subset, 1 + target, ],
-                          "bayes" =  obj$classOutput[[regrClassTarget]][subset, 1, ]))
-          }
-        }
-      }
-      ## It doesn't matter whether we process regression or classification first.
-      ## But one and only one family will be processed.
-      if (is.null(regrClassTarget)) {
-        if (!is.null(obj$regrOutput)) {
-          if (is.null(m.target)) {
-            ## Grab the first outcome!  It will exist, as this is the univariate case.
-            m.target <- names(obj$regrOutput)[1]
-          }
-          regrClassTarget <- which (names(obj$regrOutput) == m.target)
-          ## Regression.
-          if (length(regrClassTarget) > 0) {
-            if (length(regrClassTarget) > 1) {            
-              ## Safety check in case m.target was incorrect coming into this routine.
-              stop("Invalid number of target outcomes specified in partial plot extraction.")
-            }
-            n <- dim(obj$classOutput[[regrClassTarget]])[1]
-            if (missing(subset)) subset <- 1:n
-            return(obj$regrOutput[[regrClassTarget]][subset, ])
-          }
-        }
-      }
-      ## If after parsing both classification and regression we have not found the target, we error.
-      if (is.null(regrClassTarget)) {
-        stop("Invalid target specified in partial plot extraction:  ", m.target)
-      }
-    }
-}
 plot.variable <- plot.variable.rfsrc
